@@ -5,7 +5,7 @@ from typing import Type, List
 class ExtendedEnum(Enum):
     @classmethod
     def get_list_of_all_values(cls):
-        return [x for x in cls.__members__.values()]
+        return cls.__members__.values()
 
     @classmethod
     def from_string(cls, s: str) -> Type[Enum]:
